powered by
Draws the x-y geometry of a mesh in base graphics: quads (ib) and triangles (it) as polygons, segments (is) as lines, and bare vertices as points when no primitives are present.
ib
it
is
# S3 method for mesh3d plot( x, ..., asp = 1, add = FALSE, axes = TRUE, border = "black", col = NA, alpha = 1, lwd = 1, lty = 1 )
the input mesh, invisibly, called for the side effect of graphics
mesh3d object (with any or all of quads, triangles, segments)
ignored
aspect ratio, default 1
add to an existing plot, default FALSE
FALSE
draw axes (when starting a new plot), default TRUE
TRUE
border colour for polygons, default 'black'
fill colour for polygons (line colour for segments), default NA
NA
transparency in [0, 1], default 1 (opaque)
[0, 1]
line width
line type
plot(quad(c(5, 4), extent = c(0, 10, 0, 8)))
Run the code above in your browser using DataLab