This function sets the size of the window to 1024x1024, sets the view position
at directly vertical phi = 0, theta = 0, makes the view non-interactive
(zoom is enabled, but no pivot or pan). It turns off the lights and puts a
new light in front of the viewer (to avoid shiny glare), sets the aspect
ratio to 'iso' ("fill the box"), and attempts to 'bringtotop', but I think that
has to happen interactively with rgl::rgl.bringtotop() (especially for
animating or snapshotting scenes to file).
phi and theta use 0 and 0 respectively, phi is different from
rgl's default in order to look straight down on the quad (along the z axis)
light_phi and light_theta use -45 and 0 respectively, phi is different
from rg's default to put the light source forwards (y+) from the viewer when
looking straight down